@@ -4,7 +4,10 @@ from biblematetc import config
 from biblematetc.ui.selection_dialog import TerminalModeDialogs
 import os, shutil, pprint
 
-CONFIG_FILE_BACKUP = os.path.join(AGENTMAKE_USER_DIR, "biblemate", "biblematetc.config")
+BIBLEMATE_USER_DIR = os.path.join(AGENTMAKE_USER_DIR, "biblemate")
+if not os.path.isdir(BIBLEMATE_USER_DIR):
+    Path(BIBLEMATE_USER_DIR).mkdir(parents=True, exist_ok=True)
+CONFIG_FILE_BACKUP = os.path.join(BIBLEMATE_USER_DIR, "biblematetc.config")
 
 # NOTE: When add a config item, update both `write_user_config` and `default_config`
 
@@ -47,8 +50,8 @@ config.light=True
 config.web_browser=False
 config.hide_tools_order=True
 config.skip_connection_check=False
-config.default_bible="NET"
-config.default_commentary="CBSC"
+config.default_bible="CUV"
+config.default_commentary="新英語譯本"
 config.default_encyclopedia="ISB"
 config.default_lexicon="Morphology"
 config.max_semantic_matches=15
@@ -237,10 +240,12 @@ AGENTMAKE_CONFIG = {
 }
 OLLAMA_NOT_FOUND = "`Ollama` is not found! BibleMate AI uses `Ollama` to generate embeddings for semantic searches. You may install it from https://ollama.com/ so that you can perform semantic searches of the Bible with BibleMate AI."
 BIBLEMATE_VERSION = readTextFile(os.path.join(os.path.dirname(os.path.realpath(__file__)), "version.txt"))
-BIBLEMATE_USER_DIR = os.path.join(AGENTMAKE_USER_DIR, "biblemate")
-BIBLEMATEDATA = os.path.join(AGENTMAKE_USER_DIR, "biblemate", "data")
+BIBLEMATEDATA = os.path.join(BIBLEMATE_USER_DIR, "data")
 if not os.path.isdir(BIBLEMATEDATA):
     Path(BIBLEMATEDATA).mkdir(parents=True, exist_ok=True)
+BIBLEMATETEMP = os.path.join(os.path.dirname(os.path.realpath(__file__)), "temp")
+if not os.path.isdir(BIBLEMATETEMP):
+    Path(BIBLEMATETEMP).mkdir(parents=True, exist_ok=True)
 DIALOGS = TerminalModeDialogs()
 
 def fix_string(content):
